# whaTFRecordsWriter
Library for Creating TFRecords from Data

# Overview

Are you having trouble saving your precious data into an easy format for training and testing? Well, you're in luck because with `whaTFRecordsWriter` we are trying to minimize the effort required to simplify your dataset with [TFRecord]('https://www.tensorflow.org/tutorials/load_data/tfrecord'). 

# Installation

Python 3.6+ is required

```Python
pip install whaTFRecordsWriter
```
